@@ -30,18 +30,23 @@ import itertools
 import json
 import logging
 import pathlib
-import typing
 from collections import defaultdict
 from contextlib import asynccontextmanager
 from contextlib import contextmanager
 from dataclasses import dataclass
+from typing import Any
+from typing import AsyncGenerator
+from typing import AsyncIterator
+from typing import Generator
+from typing import Type
+from typing import TypeVar
 
 import trio
 from trio_websocket import ConnectionClosed as WsConnectionClosed
 from trio_websocket import connect_websocket_url
 
 logger = logging.getLogger("trio_cdp")
-T = typing.TypeVar("T")
+T = TypeVar("T")
 MAX_WS_MESSAGE_SIZE = 2**24
 
 devtools = None
@@ -184,7 +189,7 @@ class CmEventProxy:
     value set that contains the returned event.
     """
 
-    value: typing.Any = None
+    value: Any = None
 
 
 class CdpBase:
@@ -197,7 +202,7 @@ class CdpBase:
         self.inflight_cmd = {}
         self.inflight_result = {}
 
-    async def execute(self, cmd: typing.Generator[dict, T, typing.Any]) -> T:
+    async def execute(self, cmd: Generator[dict, T, Any]) -> T:
         """Execute a command on the server and wait for the result.
 
         :param cmd: any CDP command
@@ -211,13 +216,19 @@ class CdpBase:
         if self.session_id:
             request["sessionId"] = self.session_id
         request_str = json.dumps(request)
+        if logger.isEnabledFor(logging.DEBUG):
+            logger.debug(f"Sending CDP message: {cmd_id} {cmd_event}: {request_str}")
         try:
             await self.ws.send_message(request_str)
         except WsConnectionClosed as wcc:
             raise CdpConnectionClosed(wcc.reason) from None
         await cmd_event.wait()
         response = self.inflight_result.pop(cmd_id)
+        if logger.isEnabledFor(logging.DEBUG):
+            logger.debug(f"Received CDP message: {response}")
         if isinstance(response, Exception):
+            if logger.isEnabledFor(logging.DEBUG):
+                logger.debug(f"Exception raised by {cmd_event} message: {type(response).__name__}")
             raise response
         return response
 
@@ -230,7 +241,7 @@ class CdpBase:
         return receiver
 
     @asynccontextmanager
-    async def wait_for(self, event_type: typing.Type[T], buffer_size=10) -> typing.AsyncGenerator[CmEventProxy, None]:
+    async def wait_for(self, event_type: Type[T], buffer_size=10) -> AsyncGenerator[CmEventProxy, None]:
         """Wait for an event of the given type and return it.
 
         This is an async context manager, so you should open it inside
@@ -400,7 +411,7 @@ class CdpConnection(CdpBase, trio.abc.AsyncResource):
         await self.ws.aclose()
 
     @asynccontextmanager
-    async def open_session(self, target_id) -> typing.AsyncIterator[CdpSession]:
+    async def open_session(self, target_id) -> AsyncIterator[CdpSession]:
         """This context manager opens a session and enables the "simple" style
         of calling CDP APIs.
 
@@ -462,7 +473,7 @@ class CdpConnection(CdpBase, trio.abc.AsyncResource):
 
 
 @asynccontextmanager
-async def open_cdp(url) -> typing.AsyncIterator[CdpConnection]:
+async def open_cdp(url) -> AsyncIterator[CdpConnection]:
     """This async context manager opens a connection to the browser specified
     by ``url`` before entering the block, then closes the connection when the
     block exits.
